$ontext

   Data Envelopment Analysis (DEA) example

   Erwin Kalvelagen, may 2002
   Extended by Andy Johnson June 2013

   Data from:
      Timo Kuosmanen
         Finnish Electricity Distribution Data



$offtext



SETS
i                index of firms /i1*i89/
k                index of outputs /Electricity,Length,Customers/
l                index of inputs /Cost/
;
alias(i,j)
;

PARAMETERS
   dataC(i,l) 'cost data'
   Ydata(i,k) 'output data'
   x0(l)   'inputs of firm j0'
   y0(k)  'outputs of firm j0'
   x(l,i)  'inputs of firm i'
   y(k,i) 'outputs of firm i'
   transx(i,l)  'inputs of firm i'
   transy(i,k) 'outputs of firm i'
   n              sample size
   efficiency(i) 'efficiency of each DMU'
   efficiency2(i) 'efficiency for each DMU coming from the envelopment problem'
   allu(i,k) 'matrix of all u values'
   allv(i,l) 'matrix of all v values'
   alllamda(i,i) 'matrix of all lamda values'
;

$libinclude xlimport Ydata C:\Users\Andy\Documents\gamsdir\projdir\Teach\FinnishElectricityOutput.xlsx
$libinclude xlimport dataC C:\Users\Andy\Documents\gamsdir\projdir\Teach\FinnishElectricityCost.xlsx
;

x(l,i) = dataC(i,l);
y(k,i) = Ydata(i,k);
transx(i,l)=x(l,i);
transy(i,k)=y(k,i);

positive variables
   v(l)  'input weights'
   u(k) 'output weights'
   lamda 'intensity vector for constructing benchmarks'
;

variable
   eff 'efficiency'
   eff2 'efficiency from envelopment problem'
   us 'variable returns to scale'
   theta 'envelopment efficiency'

;

equations
   objective  'objective function: maximize efficiency'
   normalize  'normalize input weights'
   limit(i)   "limit other DMU's efficiency";

objective..  eff =e= sum(k, u(k)*y0(k));

normalize..  sum(l, v(l)*x0(l)) =e= 1;

limit(i)..   sum(k, u(k)*y(k,i)) =l= sum(l, v(l)*x(l,i));


model dea /objective, normalize, limit/;

equations
   objective2  'objective function: maximize efficiency'
   convexitycon  'normalize input weights'
   outputcon   ' constraints for each output'
   inputcon     'constraints for each input'
;

outputcon(k).. sum(i, lamda(i)*transy(i,k)) - y0(k) =g= 0;

inputcon(l).. sum(i, lamda(i)*transx(i,l)) - theta*x0(l) =l=     0;

convexitycon.. sum(i, lamda(i)) =e= 1;

objective2..  eff2 =e= theta;

model dea2 /objective2, outputcon, inputcon/;

alias (i,iter);




loop(iter,

   x0(l) = x(l, iter);
   y0(k) = y(k, iter);

   solve dea using lp maximizing eff;
   abort$(dea.modelstat<>1) "LP was not optimal";

   solve dea2 using lp minimizing eff2;
   abort$(dea.modelstat<>1) "LP was not optimal";

   efficiency(iter) = eff.l;
   efficiency2(iter) = eff2.l;
   allu(iter,k)=u.l(k);
   allv(iter,l)=v.l(l);
   alllamda(iter,i)=lamda.l(i);
);


display efficiency, u.l, v.l;

$libinclude xldump allu C:\Users\Andy\Documents\gamsdir\projdir\Teach\DEA_results_CRS.xlsx u a1:cw120
$libinclude xldump allv C:\Users\Andy\Documents\gamsdir\projdir\Teach\DEA_results_CRS.xlsx v a1:cw120
$libinclude xldump efficiency C:\Users\Andy\Documents\gamsdir\projdir\Teach\DEA_results_CRS.xlsx efficiency a1:cw120
$libinclude xldump efficiency2 C:\Users\Andy\Documents\gamsdir\projdir\Teach\DEA_results_CRS.xlsx efficiency2 a1:cw120
$libinclude xldump alllamda C:\Users\Andy\Documents\gamsdir\projdir\Teach\DEA_results_CRS.xlsx lamda a1:cw120