$ontext

   Data Envelopment Analysis (DEA) example

   Erwin Kalvelagen, may 2002
   Extended by Andy Johnson  June 2013

   Data from:
      Timo Kuosmanen
         Finnish Electricity Distribution Data



$offtext



SETS
i                index of firms /i1*i89/
k                index of outputs /Electricity,Length,Customers/
l                index of inputs /Cost/
;
alias(i,j)
;

PARAMETERS
   dataC(i,l) 'cost data'
   Ydata(i,k) 'output data'
   x0(l)   'inputs of firm j0'
   y0(k)  'outputs of firm j0'
   x(l,i)  'inputs of firm i'
   y(k,i) 'outputs of firm i'
   n              sample size
   efficiency(i) 'efficiency of each DMU'
;

$libinclude xlimport Ydata C:\Users\Andy\Documents\gamsdir\projdir\Teach\FinnishElectricityOutput.xlsx
$libinclude xlimport dataC C:\Users\Andy\Documents\gamsdir\projdir\Teach\FinnishElectricityCost.xlsx
;

x(l,i) = dataC(i,l);
y(k,i) = Ydata(i,k);

positive variables
   v(l)  'input weights'
   u(k) 'output weights'
;

variable
   eff 'efficiency'
   us 'variable returns to scale'
;

equations
   objective  'objective function: maximize efficiency'
   normalize  'normalize input weights'
   limit(i)   "limit other DMU's efficiency";

objective..  eff =e= sum(k, u(k)*y0(k))+ us;

normalize..  sum(l, v(l)*x0(l)) =e= 1;

limit(i)..   sum(k, u(k)*y(k,i))+ us =l= sum(l, v(l)*x(l,i));


model dea /objective, normalize, limit/;


alias (i,iter);




loop(iter,

   x0(l) = x(l, iter);
   y0(k) = y(k, iter);

   solve dea using lp maximizing eff;
   abort$(dea.modelstat<>1) "LP was not optimal";

   efficiency(iter) = eff.l;
);


display efficiency, u.l, v.l;

*
* create sorted output
*
set r /rnk1*rnk1000/;
parameter rank(i);
alias (i,ii);
rank(i) = sum(ii$(efficiency(ii)>=efficiency(i)), 1);
parameter efficiency2(r,i);
efficiency2(r,i)=efficiency(i)$(rank(i)=ord(r));
option efficiency2:4:0:1;
display efficiency2;
